@@ -1,11 +1,12 @@
 import os
 import sys
 
-from celery import Celery
-
 from django.conf import settings
 
-app = Celery('example')
+from django_celery_extensions.celery import Celery
+
+
+app = Celery('example', task_cls='security.task:LoggedTask')
 
 # Using a string here means the worker will not have to
 # pickle the object when using Windows.
